@@ -20,6 +20,7 @@ import subprocess
 # pymusepipe modules
 from . import util_pipe as upipe
 from .version import __version__ as pipeversion
+from .config_pipe import dict_products_scipost
 
 # Likwid command
 default_likwid = "likwid-pin -c N:"
@@ -56,10 +57,9 @@ class PipeRecipes(object) :
 
     @property
     def esorex(self):
-        return ("{likwid}{list_cpu} {nocache} esorex --output-dir={outputdir} {checksum}" 
-                    " --log-dir={logdir}").format(likwid=self.likwid, 
-                    list_cpu=self.list_cpu, nocache=self.nocache, outputdir=self.paths.pipe_products, 
-                    checksum=self.checksum, logdir=self.paths.esorex_log)
+        return (f"{self.likwid}{self.list_cpu} {self.nocache} esorex "
+                f"--output-dir={self.paths.pipe_products} {self.checksum}" 
+                f" --log-dir={self.paths.esorex_log}")
 
     @property
     def checksum(self):
@@ -146,14 +146,13 @@ class PipeRecipes(object) :
     def recipe_flat(self, sof, dir_flat, name_flat, dir_trace, name_trace, tpl):
         """Running the esorex muse_flat recipe
         """
-        self.run_oscommand(("{esorex} --log-file=flat_{tpl}.log muse_flat " 
-                "--nifu={nifu} {merge} {sof}").format(esorex=self.esorex, 
-                    nifu=self.nifu, merge=self.merge, sof=sof, tpl=tpl))
+        self.run_oscommand(f"{self.esorex} --log-file=flat_{tpl}.log muse_flat " 
+                           f"--nifu={self.nifu} {self.merge} {sof}")
         # Moving the MASTER FLAT and TRACE_TABLE
-        self.run_oscommand("{nocache} mv {namein}.fits {nameout}_{tpl}.fits".format(nocache=self.nocache, 
-            namein=self.joinprod(name_flat), nameout=joinpath(dir_flat, name_flat), tpl=tpl))
-        self.run_oscommand("{nocache} mv {namein}.fits {nameout}_{tpl}.fits".format(nocache=self.nocache, 
-            namein=self.joinprod(name_trace), nameout=joinpath(dir_trace, name_trace), tpl=tpl))
+        self.run_oscommand(f"{self.nocache} mv {self.joinprod(name_flat)}.fits "
+                           f"{joinpath(dir_flat, name_flat)}_{tpl}.fits")
+        self.run_oscommand(f"{self.nocache} mv {self.joinprod(name_trace)}.fits "
+                           f"{joinpath(dir_trace, name_trace)}_{tpl}.fits")
 
     def recipe_wave(self, sof, dir_wave, name_wave, tpl):
         """Running the esorex muse_wavecal recipe
@@ -270,25 +269,26 @@ class PipeRecipes(object) :
                                nocache=self.nocache, 
                                name_imain=self.joinprod(name_prod+suff_prod), 
                                fitsname=fitsname_out))
-            # Adding pointing and expo numbers as keywords
+            # Adding dataset and expo numbers as keywords
             if filter_for_alignment in fitsname_out:
-                upipe.add_key_pointing_expo(fitsname_out, iexpo, self.pointing)
+                upipe.add_key_dataset_expo(fitsname_out, iexpo, self.dataset)
 
-            # Now if in need of an alignment image and it is the filter image
-            # Copying it in the Alignment folder or write it 
-            if self._save_alignment_images and filter_for_alignment in fitsname_out \
-                and self._suffix_prealign in fitsname_out:
-                name_imageout_align = ("{name_imaout}{suffix}_P{pointing:02d}_{myfilter}"
+            # Now if in need of an alignment image and it is the prealign scipost
+            # Check that it is an image using the dictionary in config_pipe
+            # and copying it in the Alignment folder
+            if self._save_alignment_images and self._suffix_prealign in fitsname_out \
+                and dict_products_scipost['cube'][1] in fitsname_out:
+                name_imageout_align = ("{name_imaout}{suffix}_{dsname}_{myfilter}"
                                       "_{tpl}{suff_post}.fits".format(
                                       name_imaout=joinpath(self.paths.alignment,
                                                            prefix_all+"IMAGE_FOV"),
                                       myfilter=filter_for_alignment, suff_post=suff_post, 
-                                      tpl=tpl, suffix=suffix, pointing=self.pointing))
+                                      tpl=tpl, suffix=suffix, dsname=self._get_dataset_name()))
                 self.run_oscommand("{nocache} cp {fitsname} {nameima_out}".format(
                                    nocache=self.nocache, fitsname=fitsname_out,
                                    nameima_out=name_imageout_align))
-                # Adding pointing and expo numbers as keywords
-                upipe.add_key_pointing_expo(name_imageout_align, iexpo, self.pointing)
+                # Adding dataset and expo numbers as keywords
+                upipe.add_key_dataset_expo(name_imageout_align, iexpo, self.dataset)
 
     def recipe_align(self, sof, dir_products, namein_products, nameout_products, tpl, group,
             threshold=10.0, srcmin=3, srcmax=80, fwhm=5.0):
@@ -307,11 +307,11 @@ class PipeRecipes(object) :
                 name_imaout=joinpath(dir_products, nameout_prod)))
 
     def recipe_combine(self, sof, dir_products, name_products, tpl, expotype,
-            suffix_products=[""], suffix_prefinalnames=[""], 
-            save='cube', pixfrac=0.6, suffix="", 
+            suffix_products=(""), suffix_prefinalnames=(""),
+            prefix_products=(""), save='cube', pixfrac=0.6, suffix="",
             format_out='Cube', filter_list='white',
             lambdamin=4000., lambdamax=10000.):
-        """Running the muse_exp_combine recipe for one single pointing
+        """Running the muse_exp_combine recipe for one single dataset
         """
         self.run_oscommand("{esorex}  --log-file=exp_combine_cube_{expotype}_{tpl}.log "
                " muse_exp_combine --save={save} --pixfrac={pixfrac:0.2f} "
@@ -321,43 +321,31 @@ class PipeRecipes(object) :
                    pixfrac=pixfrac, form=format_out, filt=filter_list, sof=sof, 
                    tpl=tpl, expotype=expotype, lmin=lambdamin, lmax=lambdamax))
 
-        for name_prod, suff_prod, suff_pre in zip(name_products, suffix_products, 
-                suffix_prefinalnames):
+        for name_prod, suff_prod, suff_pre, pre_prod in zip(name_products, suffix_products, 
+                suffix_prefinalnames, prefix_products):
 
-            self.run_oscommand("{nocache} mv {name_imain}.fits "
-                '{name_imaout}{suffix}{suff_pre}_{pointing}_{tpl}.fits'.format(nocache=self.nocache,
-                name_imain=self.joinprod(name_prod+suff_prod), 
-                name_imaout=joinpath(dir_products, name_prod),
-                suff_pre=suff_pre, suffix=suffix, 
-                tpl=tpl, pointing="P{0:02d}".format(self.pointing)))
+            self.run_oscommand(f"{self.nocache} mv {self.joinprod(name_prod+suff_prod)}.fits "
+                               f"{joinpath(dir_products, pre_prod+name_prod)}"
+                               f"{suffix}{suff_pre}_{self._get_dataset_name()}_{tpl}.fits")
 
-    def recipe_combine_pointings(self, sof, dir_products, name_products,
-            suffix_products=[""], suffix_prefinalnames=[""], 
-            prefix_products=[""], save='cube', pixfrac=0.6, suffix="", 
+    def recipe_combine_datasets(self, sof, dir_products, name_products,
+            suffix_products=(""), suffix_prefinalnames=(""),
+            prefix_products=(""), save='cube', pixfrac=0.6, suffix="",
             format_out='Cube', filter_list='white', 
             lambdamin=4000., lambdamax=10000.):
-        """Running the muse_exp_combine recipe for pointings
+        """Running the muse_exp_combine recipe for datasets
         """
-        self.run_oscommand("{esorex}  --log-file=exp_combine_pointings.log "
-               " muse_exp_combine --save={save} --pixfrac={pixfrac:0.2f} "
-               "--format={form} --filter={filt} "
-               "--lambdamin={lmin} --lambdamax={lmax} "
-               "{sof}".format(esorex=self.esorex, 
-                   save=save, pixfrac=pixfrac, form=format_out, 
-                   filt=filter_list, sof=sof, 
-                   lmin=lambdamin, lmax=lambdamax))
+        self.run_oscommand(f"{self.esorex}  --log-file=exp_combine_datasets.log "
+                           f" muse_exp_combine --save={save} --pixfrac={pixfrac:0.2f} "
+                           f"--format={format_out} --filter={filter_list} "
+                           f"--lambdamin={lambdamin} --lambdamax={lambdamax} "
+                           f"{sof}")
 
         for name_prod, suff_prod, suff_pre, pre_prod in zip(name_products, suffix_products, 
                 suffix_prefinalnames, prefix_products):
 
-            name_imaout = "{name_imaout}{suffix}{suff_pre}.fits".format(
-                         name_imaout=joinpath(dir_products, pre_prod+name_prod),
-                         suff_pre=suff_pre, suffix=suffix)
-            self.run_oscommand("{nocache} mv {name_imain}.fits "
-                              "{name_imaout}".format(
-                                  nocache=self.nocache, 
-                                  name_imain=self.joinprod(name_prod+suff_prod), 
-                                  name_imaout=name_imaout))
+            name_imaout = f"{joinpath(dir_products, pre_prod+name_prod)}{suffix}{suff_pre}.fits"
+            self.run_oscommand(f"{self.nocache} mv {self.joinprod(name_prod+suff_prod)}.fits "
+                               f"{name_imaout}")
             if "DATACUBE" in name_imaout:
                 self._combined_cube_name = name_imaout
-
