@@ -786,7 +786,9 @@ def filter_list_with_pdict(input_list, list_datasets=None,
                                 nexpo = int(expo[0])
                                 pointing = int(expo[1])
                             else:
-                                upipe.print_warning(f"Dictionary entry {expotuple} ignored")
+                                upipe.print_warning(f"Dictionary entry {expotuple} "
+                                                    f"ignored (type of expo - {expo} - "
+                                                    f"is {type(expo)}")
                                 break
 
                             # Check whether this exists in the our cube list
@@ -794,7 +796,7 @@ def filter_list_with_pdict(input_list, list_datasets=None,
                             for filename in input_list:
                                 ftpl, fnexpo = get_tpl_nexpo(filename)
 #                                if (suffix_expo in filename) and (tpl in filename):
-                                if (nexpo == fnexpo) & (ftpl == tpl):
+                                if (nexpo == int(fnexpo)) & (ftpl == tpl):
                                     # We select the file
                                     selected_filename_list.append(filename)
                                     if pointing not in dict_exposures_per_pointing:
